@@ -254,9 +254,9 @@ def separateModes(args):
     if not args:
         return []
     modes = args[0]
-    assert modes[0] in '+-', 'Invalid args: %r' % args
     args = list(args[1:])
     ret = []
+    last = '+'
     for c in modes:
         if c in '+-':
             last = c
@@ -596,12 +596,9 @@ class FormatParser(object):
         else:
             self.ungetChar(c)
 
-def wrap(s, length, break_on_hyphens = False, break_long_words = False):
+def wrap(s, length, break_on_hyphens = False):
     processed = []
-    wrapper = textwrap.TextWrapper(width=length)
-    wrapper.break_long_words = break_long_words
-    wrapper.break_on_hyphens = break_on_hyphens
-    chunks = wrapper.wrap(s)
+    chunks = utils.str.byteTextWrap(s, length)
     context = None
     for chunk in chunks:
         if context is not None:
@@ -819,7 +816,7 @@ def standardSubstitute(irc, msg, text, env=None):
         'm': localtime[4], 'min': localtime[4], 'minute': localtime[4],
         's': localtime[5], 'sec': localtime[5], 'second': localtime[5],
         'tz': time.strftime('%Z', localtime),
-        'version': 'Limnoria %s' % version,
+        'version': version,
         })
     if irc:
         vars.update({
